@@ -1,6 +1,6 @@
-use std::path::Path;
-use std::fs::metadata;
 use path_clean::PathClean;
+use std::fs::metadata;
+use std::path::Path;
 
 const VERSION: &'static str = env!("CARGO_PKG_VERSION");
 
@@ -11,7 +11,8 @@ fn print_error<T: std::string::ToString>(err: T) {
 fn print_help(args: Vec<String>) {
     println!(
         "totall v{} \
-        \nUsage: {} <file/folder>", VERSION, args[0]
+        \nUsage: {} <file/folder>",
+        VERSION, args[0]
     )
 }
 
@@ -21,14 +22,14 @@ fn absolute_path(path: impl AsRef<Path>) -> std::io::Result<std::path::PathBuf>
         path.to_path_buf()
     } else {
         std::env::current_dir()?.join(path)
-    }.clean();
+    }
+    .clean();
 
     Ok(absolute_path)
 }
 
-fn get_all_files(dir_name: &str) -> Result<Vec<String>, std::io::Error>
-{
-    let mut all_files: Vec<String> = vec!();
+fn get_all_files(dir_name: &str) -> std::io::Result<Vec<String>> {
+    let mut all_files: Vec<String> = vec![];
     let paths;
     if let Some(var) = std::fs::read_dir(dir_name).ok() {
         paths = var;
@@ -49,58 +50,51 @@ fn get_all_files(dir_name: &str) -> Result<Vec<String>, std::io::Error>
         if md.is_dir() {
             all_files.append(&mut get_all_files(full_path_str)?);
         } else if md.is_file() {
-            all_files.append(&mut vec!(full_path_str.to_string()));
+            all_files.append(&mut vec![full_path_str.to_string()]);
         }
     }
     Ok(all_files)
 }
 
-fn read_lines(file_name: String) -> Result<usize, std::io::Error> {
+fn read_lines(file_name: String) -> std::io::Result<usize> {
     Ok(linecount::count_lines(std::fs::File::open(file_name)?)? + 1)
 }
 
+fn path_count(path: &str) -> std::io::Result<usize> {
+    let md = metadata(path).unwrap();
+    if md.is_dir() {
+        let mut count: usize = 0;
+        for file in get_all_files(path)? {
+            count += read_lines(file)?;
+        }
+        Ok(count)
+    } else {
+        read_lines(path.to_string())
+    }
+}
+
 fn main() {
-    let args: Vec<String> = std::env::args().collect();
+    let args = std::env::args();
 
     if args.len() < 2 {
-        print_help(args);
+        print_help(args.collect());
         return;
     }
 
-    let path: &str = &args[1];
-    if Path::new(path).exists() {
-        let md = metadata(path).unwrap();
-        if md.is_dir() {
-            let files: Vec<String> = match get_all_files(path) {
-                Ok(m) => m,
+    let mut count: usize = 0;
+    for path in args.skip(1) {
+        if Path::new(&path).exists() {
+            count += match path_count(&path) {
+                Ok(s) => s,
                 Err(err) => {
                     print_error(err);
                     return;
                 }
             };
-
-            let mut count: usize = 0;
-            for file in files {
-                count += match read_lines(file) {
-                    Ok(m) => m,
-                    Err(err) => {
-                        print_error(err);
-                        continue;
-                    }
-                };
-            }
-            println!("{}", count);
-
-        } else if md.is_file() {
-            println!("{}", match read_lines(path.to_string()) {
-                Ok(m) => m,
-                Err(err) => {
-                    print_error(err);
-                    return;
-                }
-            });
+        } else {
+            print_error(format!("Path does not exist: {}", path));
         }
-    } else {
-        print_error("Given path does not exist.");
     }
-}
\ No newline at end of file
+
+    println!("{}", count);
+}
